@@ -38,6 +38,7 @@ class HyperV:
     # Запрос свободной памяти на гипервизоре
     @property
     def get_free_memory(self):
+        
         ps = "(Get-WMIObject Win32_OperatingSystem).FreePhysicalMemory / 1MB"
         r = self.session.run_ps(ps)
         if r.status_code == 0:
@@ -143,11 +144,11 @@ class HyperV:
         logging.debug(f"result status_code \n{result.status_code}")
         if result.status_code == '1':
             return False
-           
+                
         r_result = {}
-        for line in result.std_out.decode('utf-8').splitlines():
-            if line and not 'Name' in line and not '----' in line:
-                # print(line.split()[1])
+        r = re.findall(r"-\r\n([\w\W]*)", result.std_out.decode('utf-8'))[0]
+        for line in r.splitlines():
+            if line:
                 r_result.setdefault(line.split()[0], dict(zip(state_keys, (line.split()[1:5]))))
         return r_result
     
